==> haskell-expiring-cache-map-0.0.6.1-325-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-1wvGF3sviknHxZNec0lFyy
key:                  expiring-cache-map-0.0.6.1-1wvGF3sviknHxZNec0lFyy
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  f418078e8b8d5ce0c7cda00f9497260b
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-1wvGF3sviknHxZNec0lFyy
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal
    unordered-containers-0.2.20-9qtKP8IRTHnKAJSp2mdpwo

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-326-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-JRnLeU7Kdly8G6guvbV4yL
key:                  expiring-cache-map-0.0.6.1-JRnLeU7Kdly8G6guvbV4yL
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  c8c642b621208812dde3a8c1b0d7d952
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-JRnLeU7Kdly8G6guvbV4yL
depends:
    base-4.16.4.0 containers-0.6.5.1
    hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj
    unordered-containers-0.2.20-KbuohGKDXjMH23185MHhrF

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
